@@ -20,9 +20,10 @@ class IvvAssBackend : public AbstractBackend
     Q_PROPERTY(QJsonObject extraArguments MEMBER m_extraArgs)
 
 public:
-    [[nodiscard]] static inline constexpr const char* type() { return "ivvass"; }
+    [[nodiscard]] static constexpr const char* type() { return "ivvass"; }
 
     [[nodiscard]] Capabilities capabilities() const override;
+    [[nodiscard]] Location::Types supportedLocationTypes() const override;
     [[nodiscard]] bool needsLocationQuery(const Location &loc, AbstractBackend::QueryType type) const override;
     [[nodiscard]] bool queryLocation(const LocationRequest &req, LocationReply *reply, QNetworkAccessManager *nam) const override;
     [[nodiscard]] bool queryStopover(const StopoverRequest &req, StopoverReply *reply, QNetworkAccessManager *nam) const override;
