@@ -44,6 +44,11 @@ AbstractBackend::Capabilities Motis2Backend::capabilities() const
     return c;
 }
 
+Location::Types Motis2Backend::supportedLocationTypes() const
+{
+    return Location::Stop | Location::Address;
+}
+
 bool Motis2Backend::needsLocationQuery(const Location &loc, AbstractBackend::QueryType type) const
 {
     if (type == QueryType::Journey) {
@@ -65,11 +70,6 @@ static void filterLocations(std::vector<Location> &locations, Location::Types ty
 
 bool Motis2Backend::queryLocation(const LocationRequest &req, LocationReply *reply, QNetworkAccessManager *nam) const
 {
-    if ((req.types() & (Location::Stop|Location::Address)) == 0) {
-        // only stop and address searches are supported
-        return false;
-    }
-
     QUrlQuery query;
     QNetworkReply *netReply = nullptr;
 
@@ -104,12 +104,19 @@ bool Motis2Backend::queryLocation(const LocationRequest &req, LocationReply *rep
 
     if (req.hasCoordinate()) {
         query.addQueryItem(u"place"_s, QString::number(req.latitude()) + ','_L1 + QString::number(req.longitude()));
+        if (req.types() == Location::Stop) {
+            query.addQueryItem(u"type"_s, u"STOP"_s);
+        } else if (req.types() == Location::Address) {
+            query.addQueryItem(u"type"_s, u"ADDRESS"_s);
+        }
         netReply = makeRequest(req, reply, "v1/reverse-geocode"_L1, query, nam);
     } else {
         query.addQueryItem(u"text"_s, req.name());
         query.addQueryItem(u"language"_s, preferredLanguage());
         if (req.types() == Location::Stop) {
             query.addQueryItem(u"type"_s, u"STOP"_s);
+        } else if (req.types() == Location::Address) {
+            query.addQueryItem(u"type"_s, u"ADDRESS"_s);
         }
         if (req.viewbox().isValid()) {
             query.addQueryItem(u"place"_s, QString::number(req.viewbox().center().y()) + ','_L1 + QString::number(req.viewbox().center().x()));
@@ -158,7 +165,7 @@ bool Motis2Backend::queryStopover(const StopoverRequest &req, StopoverReply *rep
     }
     query.addQueryItem(u"radius"_s, u"200"_s);
 
-    auto netReply = makeRequest(req, reply, "v1/stoptimes"_L1, query, nam);
+    auto netReply = makeRequest(req, reply, "v4/stoptimes"_L1, query, nam);
     QObject::connect(netReply, &QNetworkReply::finished, reply, [this, netReply, reply, req]() {
         netReply->deleteLater();
         const auto data = netReply->readAll();
@@ -212,7 +219,7 @@ struct {
     { Line::LongDistanceTrain, "NIGHT_RAIL" },
     { Line::Metro, "SUBWAY" },
     { Line::RailShuttle, "RAIL" },
-    { Line::RapidTransit, "METRO" },
+    { Line::RapidTransit, "SUBURBAN" },
     { Line::Shuttle, "BUS" },
     { Line::Shuttle, "COACH" },
     { Line::Taxi, "FLEXIBLE" },
@@ -221,7 +228,8 @@ struct {
     { Line::Tramway, "TRAM" },
     { Line::Tramway, "CABLE_CAR" },
     { Line::RideShare, "CAR_SHARING" },
-    { Line::AerialLift, "AREAL_LIFT" },
+    { Line::RideShare, "RIDE_SHARING" },
+    { Line::AerialLift, "AERIAL_LIFT" },
 };
 
 struct {
@@ -238,6 +246,7 @@ struct {
     { IndividualTransport::Car, IndividualTransport::Rent, "RENTAL", "CAR" },
     { IndividualTransport::Car, IndividualTransport::Park, "CAR_PARKING", nullptr },
     // { IndividualTransport::Car, IndividualTransport::Pickup, "CAR_PICKUP", nullptr }, // TODO removed in later v2 versions again
+    { IndividualTransport::Car, IndividualTransport::Dropoff, "CAR_DROPOFF", nullptr },
     { IndividualTransport::Car, IndividualTransport::None, "CAR", nullptr },
 };
 
@@ -344,7 +353,7 @@ bool Motis2Backend::queryJourney(const JourneyRequest &req, JourneyReply *reply,
     }
     query.addQueryItem(u"arriveBy"_s, req.dateTimeMode() == JourneyRequest::Arrival ? u"true"_s : u"false"_s);
 
-    auto netReply = makeRequest(req, reply, "v3/plan"_L1, query, nam);
+    auto netReply = makeRequest(req, reply, "v4/plan"_L1, query, nam);
     QObject::connect(netReply, &QNetworkReply::finished, reply, [this, netReply, reply]() {
         netReply->deleteLater();
         const auto data = netReply->readAll();
@@ -374,7 +383,7 @@ bool Motis2Backend::queryTrip(const TripRequest &req, TripReply *reply, QNetwork
 
     QUrlQuery query;
     query.addQueryItem(u"tripId"_s, tripId);
-    auto netReply = makeRequest(req, reply, "v2/trip"_L1, query, nam);
+    auto netReply = makeRequest(req, reply, "v4/trip"_L1, query, nam);
     QObject::connect(netReply, &QNetworkReply::finished, reply, [this, netReply, reply]() {
         netReply->deleteLater();
         const auto data = netReply->readAll();
