@@ -5,10 +5,12 @@
 
 #include "motis2parser.h"
 #include "geo/polylinedecoder_p.h"
+#include "gtfs/hvt.h"
 
 #include <KPublicTransport/Journey>
 #include <KPublicTransport/Location>
 #include <KPublicTransport/RentalVehicle>
+#include <KPublicTransport/StopInformation>
 #include <KPublicTransport/Stopover>
 
 #include <KCountry>
@@ -88,6 +90,9 @@ struct {
     { "FUNICULAR", Line::Mode::Funicular, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
     { "AREAL_LIFT", Line::Mode::AerialLift, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
     { "OTHER", Line::Mode::Unknown, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
+    { "AERIAL_LIFT", Line::Mode::RapidTransit, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
+    { "SUBURBAN", Line::Mode::RapidTransit, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
+    { "RIDE_SHARING", Line::Mode::RideShare, JourneySection::PublicTransport, IndividualTransport::Car, IndividualTransport::None, RentalVehicle::Car },
 };
 
 struct {
@@ -165,6 +170,43 @@ Stopover Motis2Parser::parsePlace(const QJsonObject &obj, bool hasRealTime) cons
     return s;
 }
 
+Route Motis2Parser::parseRoute(const QJsonObject &obj) const
+{
+    Line line;
+    Route route;
+
+    if (const auto mode = Gtfs::Hvt::typeToMode(obj.value("routeType"_L1).toInt(-1)); mode != Line::Unknown) {
+        line.setMode(mode);
+    } else {
+        const auto modeClass = obj.value("mode"_L1).toString();
+        for (const auto &m : mode_map) {
+            if (QLatin1StringView(m.name) == modeClass) {
+                line.setMode(m.lineMode);
+                break;
+            }
+        }
+    }
+
+    line.setName(obj.value("displayName"_L1).toString());
+    if (line.name().isEmpty()) {
+        line.setName(obj.value("routeShortName"_L1).toString());
+    }
+    if (const auto tripName = obj.value("tripShortName"_L1).toString(); !tripName.isEmpty() && !line.name().contains(tripName)) {
+        route.setName(tripName);
+    }
+
+    line.setOperatorName(obj.value("agencyName"_L1).toString());
+    line.setOperatorUrl(QUrl(obj.value("agencyUrl"_L1).toString()));
+    line.setColor(QColor::fromString('#'_L1 + obj.value("routeColor"_L1).toString()));
+    line.setTextColor(QColor::fromString('#'_L1 + obj.value("routeTextColor"_L1).toString()));
+
+    route.setDirection(obj.value("headsign"_L1).toString());
+    route.setDestination(parsePlace(obj.value("tripTo"_L1).toObject(), false).stopPoint());
+    route.setLine(line);
+
+    return route;
+}
+
 [[nodiscard]] static QPolygonF parsePolyLine(const QJsonObject &encodedPolyline)
 {
     QPolygonF poly;
@@ -222,7 +264,12 @@ Journey Motis2Parser::parseItinerary(const QJsonObject &itinerary) const
         s.setMode((*it).jnyMode);
 
         const auto hasRealTime = leg.value("realTime"_L1).toBool();
-        const auto from = parsePlace(leg.value("from"_L1).toObject(), hasRealTime);
+        auto from = parsePlace(leg.value("from"_L1).toObject(), hasRealTime);
+        std::vector<Feature> features;
+        if (leg["mode"_L1] == "NIGHT_RAIL"_L1) {
+            features.push_back(Feature(Feature::SleeperCompartment));
+        }
+        from.setFeatures(std::move(features));
         s.setDeparture(from);
         const auto to = parsePlace(leg.value("to"_L1).toObject(), hasRealTime);
         s.setArrival(to);
@@ -237,19 +284,7 @@ Journey Motis2Parser::parseItinerary(const QJsonObject &itinerary) const
 
         if (s.mode() == JourneySection::PublicTransport) {
             s.setIdentifier(m_locIdentifierType, leg.value("tripId"_L1).toString());
-
-            Line line;
-            line.setMode((*it).lineMode);
-            line.setName(leg.value("routeShortName"_L1).toString());
-            line.setOperatorName(leg.value("agencyName"_L1).toString());
-            line.setColor(QColor::fromString('#'_L1 + leg.value("routeColor"_L1).toString()));
-            line.setTextColor(QColor::fromString('#'_L1 + leg.value("routeTextColor"_L1).toString()));
-
-            Route route;
-            route.setDirection(leg.value("headsign"_L1).toString());
-            route.setLine(line);
-
-            s.setRoute(route);
+            s.setRoute(parseRoute(leg));
 
             const auto intermediateStops = leg.value("intermediateStops"_L1).toArray();
             std::vector<Stopover> stops;
@@ -276,6 +311,7 @@ Journey Motis2Parser::parseItinerary(const QJsonObject &itinerary) const
 
             RentalVehicleNetwork rvNetwork;
             rvNetwork.setName(rentalObj.value("systemName"_L1).toString());
+            rvNetwork.setUrl(QUrl(rentalObj.value("url"_L1).toString()));
 
             RentalVehicle rv;
             rv.setType((*it).rentalType);
@@ -348,26 +384,10 @@ std::vector<Stopover> Motis2Parser::parseStopTimes(const QByteArray &data, bool
     result.reserve(stopTimes.size());
     for (const auto &stopV : stopTimes) {
         const auto stop = stopV.toObject();
-        Line line;
-        const auto mode = stop.value("mode"_L1).toString();
-        for (const auto &m : mode_map) {
-            if (QLatin1StringView(m.name) == mode) {
-                line.setMode(m.lineMode);
-                break;
-            }
-        }
-        line.setName(stop.value("routeShortName"_L1).toString());
-        line.setOperatorName(stop.value("agencyName"_L1).toString());
-        line.setColor(QColor::fromString('#'_L1 + stop.value("routeColor"_L1).toString()));
-        line.setTextColor(QColor::fromString('#'_L1 + stop.value("routeTextColor"_L1).toString()));
-        Route route;
-        route.setLine(line);
-        route.setDirection(stop.value("headsign"_L1).toString());
-
         const auto hasRealTime = stop.value("realTime"_L1).toBool();
         auto s = parsePlace(stop.value("place"_L1).toObject(), hasRealTime);
         s.setTripIdentifier(m_locIdentifierType, stop.value("tripId"_L1).toString());
-        s.setRoute(route);
+        s.setRoute(parseRoute(stop));
 
         if (stop.value("cancelled"_L1).toBool()) {
             s.setDisruptionEffect(Disruption::NoService);
@@ -475,6 +495,27 @@ std::vector<Location> Motis2Parser::parseLocations(const QByteArray &data) const
         l.setStreetAddress(QString(locObj.value("street"_L1).toString() + ' '_L1 + locObj.value("houseNumber"_L1).toString()).trimmed());
 
         parseTimeZone(locObj, l);
+
+        if (l.type() == Location::Stop) {
+            StopInformation stopInfo;
+            const auto modes = locObj.value("modes"_L1).toArray();
+            for (const auto &mode : modes) {
+                const auto it = std::ranges::find_if(mode_map, [&mode](const auto &m) {
+                    return QLatin1StringView(m.name) == mode;
+                });
+                if (it == std::end(mode_map)) {
+                    qWarning() << "Unknown mode:" << mode;
+                    continue;
+                }
+                Line l;
+                l.setMode((*it).lineMode);
+                stopInfo.addLine(l);
+            }
+            if (!stopInfo.lines().empty()) {
+                l.setData(stopInfo);
+            }
+        }
+
         result.push_back(std::move(l));
     }
 
