@@ -30,6 +30,7 @@ public:
     QColor textColor;
     LineMetaData metaData;
     QString operatorName;
+    QUrl operatorUrl;
 };
 
 class RoutePrivate : public QSharedData {
@@ -48,10 +49,11 @@ KPUBLICTRANSPORT_MAKE_PROPERTY(Line, QColor, textColor, setTextColor)
 KPUBLICTRANSPORT_MAKE_PROPERTY(Line, Line::Mode, mode, setMode)
 KPUBLICTRANSPORT_MAKE_PROPERTY(Line, QString, modeString, setModeString)
 KPUBLICTRANSPORT_MAKE_PROPERTY(Line, QString, operatorName, setOperatorName)
+KPUBLICTRANSPORT_MAKE_PROPERTY(Line, QUrl, operatorUrl, setOperatorUrl)
 
 QColor Line::color() const
 {
-    return d->metaData.color().isValid() ? d->metaData.color() : d->color;
+    return (!name().isEmpty() && d->metaData.color().isValid()) ? d->metaData.color() : d->color;
 }
 
 void Line::setColor(const QColor &value)
@@ -62,7 +64,7 @@ void Line::setColor(const QColor &value)
 
 bool Line::hasColor() const
 {
-    return d->color.isValid() || d->metaData.color().isValid();
+    return d->color.isValid() || (!name().isEmpty() && d->metaData.color().isValid());
 }
 
 bool Line::hasTextColor() const
@@ -72,7 +74,7 @@ bool Line::hasTextColor() const
 
 QString Line::logo() const
 {
-    return AssetRepository::localFile(d->metaData.logoUrl()).toString(QUrl::FullyEncoded);
+    return !name().isEmpty() ? AssetRepository::localFile(d->metaData.logoUrl()).toString(QUrl::FullyEncoded) : QString();
 }
 
 bool Line::hasLogo() const
@@ -216,16 +218,21 @@ Line Line::merge(const Line &lhs, const Line &rhs)
     }
 
     l.setOperatorName(MergeUtil::mergeString(lhs.operatorName(), rhs.operatorName()));
+    l.setOperatorUrl(MergeUtil::mergeUrl(lhs.operatorUrl(), rhs.operatorUrl()));
     return l;
 }
 
 void Line::applyMetaData(const Location &location, bool download)
 {
-    if (name().isEmpty() || !location.hasCoordinate()) {
+    if (!location.hasCoordinate()) {
         return;
     }
 
-    d->metaData = LineMetaData::find(location.latitude(), location.longitude(), name(), mode());
+    if (!name().isEmpty()) {
+        d->metaData = LineMetaData::find(location.latitude(), location.longitude(), name(), mode());
+    } else {
+        d->metaData = LineMetaData::find(location.latitude(), location.longitude(), mode());
+    }
 
     if (download && AssetRepository::instance()) {
         AssetRepository::instance()->download(d->metaData.logoUrl());
@@ -242,12 +249,22 @@ QJsonObject Line::toJson(const Line &l)
     return obj;
 }
 
+QJsonArray Line::toJson(const std::vector<Line> &lines)
+{
+    return Json::toJson(lines);
+}
+
 Line Line::fromJson(const QJsonObject &obj)
 {
     auto l = Json::fromJson<Line>(obj);
     return l;
 }
 
+std::vector<Line> Line::fromJson(const QJsonArray &array)
+{
+    return Json::fromJson<Line>(array);
+}
+
 
 KPUBLICTRANSPORT_MAKE_GADGET(Route)
 KPUBLICTRANSPORT_MAKE_PROPERTY(Route, Line, line, setLine)
